@@ -168,9 +168,11 @@ def validate_os_resources(context, cluster_template, cluster=None):
         validate_keypair(cli, cluster['keypair'])
 
 
-def validate_master_count(cluster, cluster_template):
-    if cluster['master_count'] > 1 and \
-            not cluster['master_lb_enabled']:
+def validate_master_count(context, cluster):
+    if (
+        cluster['master_count'] > 1 and
+        not cluster['master_lb_enabled']
+    ):
         raise exception.InvalidParameterValue(_(
             "master_count must be 1 when master_lb_enabled is False"))
 
