@@ -15,13 +15,12 @@
 import itertools
 
 from magnum.common.policies import base
-from magnum.common.policies import bay
-from magnum.common.policies import baymodel
 from magnum.common.policies import certificate
 from magnum.common.policies import cluster
 from magnum.common.policies import cluster_template
 from magnum.common.policies import federation
 from magnum.common.policies import magnum_service
+from magnum.common.policies import nodegroup
 from magnum.common.policies import quota
 from magnum.common.policies import stats
 
@@ -29,13 +28,12 @@ from magnum.common.policies import stats
 def list_rules():
     return itertools.chain(
         base.list_rules(),
-        bay.list_rules(),
-        baymodel.list_rules(),
         certificate.list_rules(),
         cluster.list_rules(),
         cluster_template.list_rules(),
         federation.list_rules(),
         magnum_service.list_rules(),
         quota.list_rules(),
-        stats.list_rules()
+        stats.list_rules(),
+        nodegroup.list_rules()
     )
