@@ -23,20 +23,18 @@ down_revision = '6f21dc998bb'
 
 from alembic import op  # noqa: E402
 
-from oslo_db.sqlalchemy.types import String  # noqa: E402
+from sqlalchemy.types import String  # noqa: E402
 
 import sqlalchemy as sa  # noqa: E402  # noqa: E402
 
-from sqlalchemy.dialects.mysql import TINYTEXT  # noqa: E402
-
 
 def upgrade():
     op.add_column('baymodel', sa.Column('http_proxy',
-                                        String(255, mysql_ndb_type=TINYTEXT),
+                                        String(255),
                                         nullable=True))
     op.add_column('baymodel', sa.Column('https_proxy',
-                                        String(255, mysql_ndb_type=TINYTEXT),
+                                        String(255),
                                         nullable=True))
     op.add_column('baymodel', sa.Column('no_proxy',
-                                        String(255, mysql_ndb_type=TINYTEXT),
+                                        String(255),
                                         nullable=True))
