@@ -46,7 +46,8 @@ class TestClusterResize(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   {"node_count": new_node_count},
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.7"})
+                                           "container-infra 1.7",
+                                           "X-Roles": "member"})
         self.assertEqual(202, response.status_code)
 
         response = self.get_json('/clusters/%s' % self.cluster_obj.uuid)
@@ -69,7 +70,8 @@ class TestClusterResize(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_resize_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"})
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"})
         self.assertEqual(202, response.status_code)
 
         response = self.get_json('/clusters/%s' % self.cluster_obj.uuid)
@@ -78,8 +80,8 @@ class TestClusterResize(api_base.FunctionalTest):
         self.assertEqual(self.cluster_obj.cluster_template_id,
                          response['cluster_template_id'])
 
-    def test_resize_with_master_nodegroup(self):
-        new_node_count = 6
+    def test_resize_with_master_nodegroup_even_unsupported(self):
+        new_node_count = 4
         nodegroup = self.cluster_obj.default_ng_master
         cluster_resize_req = {
             "node_count": new_node_count,
@@ -89,7 +91,24 @@ class TestClusterResize(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_resize_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"},
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"},
+                                  expect_errors=True)
+        self.assertEqual(400, response.status_code)
+
+    def test_resize_with_master_nodegroup_odd_unsupported(self):
+        new_node_count = 3
+        nodegroup = self.cluster_obj.default_ng_master
+        cluster_resize_req = {
+            "node_count": new_node_count,
+            "nodegroup": nodegroup.uuid
+        }
+        response = self.post_json('/clusters/%s/actions/resize' %
+                                  self.cluster_obj.uuid,
+                                  cluster_resize_req,
+                                  headers={"Openstack-Api-Version":
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"},
                                   expect_errors=True)
         self.assertEqual(400, response.status_code)
 
@@ -106,7 +125,8 @@ class TestClusterResize(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_resize_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"},
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"},
                                   expect_errors=True)
         self.assertEqual(400, response.status_code)
 
@@ -123,7 +143,8 @@ class TestClusterResize(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_resize_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"},
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"},
                                   expect_errors=True)
         self.assertEqual(400, response.status_code)
 
@@ -140,7 +161,8 @@ class TestClusterResize(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_resize_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"},
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"},
                                   expect_errors=True)
         self.assertEqual(400, response.status_code)
 
@@ -157,7 +179,8 @@ class TestClusterResize(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_resize_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.10"})
+                                           "container-infra 1.10",
+                                           "X-Roles": "member"})
         self.assertEqual(202, response.status_code)
 
 
@@ -195,7 +218,8 @@ class TestClusterUpgrade(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_upgrade_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.8"})
+                                           "container-infra 1.8",
+                                           "X-Roles": "member"})
         self.assertEqual(202, response.status_code)
 
     def test_upgrade_cluster_as_admin(self):
@@ -226,7 +250,8 @@ class TestClusterUpgrade(api_base.FunctionalTest):
             '/clusters/%s/actions/upgrade' %
             cluster_uuid,
             cluster_upgrade_req,
-            headers={"Openstack-Api-Version": "container-infra 1.8"})
+            headers={"Openstack-Api-Version": "container-infra 1.8",
+                     "X-Roles": "member"})
 
         self.assertEqual(202, response.status_int)
 
@@ -239,7 +264,8 @@ class TestClusterUpgrade(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_upgrade_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"})
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"})
         self.assertEqual(202, response.status_code)
 
     def test_upgrade_default_master(self):
@@ -251,7 +277,8 @@ class TestClusterUpgrade(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_upgrade_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"})
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"})
         self.assertEqual(202, response.status_code)
 
     def test_upgrade_non_default_ng(self):
@@ -263,7 +290,8 @@ class TestClusterUpgrade(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_upgrade_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"})
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"})
         self.assertEqual(202, response.status_code)
 
     def test_upgrade_cluster_not_found(self):
@@ -273,7 +301,8 @@ class TestClusterUpgrade(api_base.FunctionalTest):
         response = self.post_json('/clusters/not_there/actions/upgrade',
                                   cluster_upgrade_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.8"},
+                                           "container-infra 1.8",
+                                           "X-Roles": "member"},
                                   expect_errors=True)
         self.assertEqual(404, response.status_code)
 
@@ -285,7 +314,8 @@ class TestClusterUpgrade(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_upgrade_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.8"},
+                                           "container-infra 1.8",
+                                           "X-Roles": "member"},
                                   expect_errors=True)
         self.assertEqual(404, response.status_code)
 
@@ -298,7 +328,8 @@ class TestClusterUpgrade(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_upgrade_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"},
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"},
                                   expect_errors=True)
         self.assertEqual(404, response.status_code)
 
@@ -311,6 +342,7 @@ class TestClusterUpgrade(api_base.FunctionalTest):
                                   self.cluster_obj.uuid,
                                   cluster_upgrade_req,
                                   headers={"Openstack-Api-Version":
-                                           "container-infra 1.9"},
+                                           "container-infra 1.9",
+                                           "X-Roles": "member"},
                                   expect_errors=True)
         self.assertEqual(409, response.status_code)
