@@ -10,7 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import mock
+from unittest import mock
+
 from oslo_config import fixture
 
 from keystoneauth1 import exceptions as ka_exception
@@ -70,6 +71,9 @@ class KeystoneClientTest(base.TestCase):
 
     def test_client_with_password(self, mock_ks):
         self.ctx.is_admin = True
+        self.ctx.auth_token_info = None
+        self.ctx.auth_token = None
+        self.ctx.trust_id = None
         ks_client = keystone.KeystoneClientV3(self.ctx)
         ks_client.client
         session = ks_client.session
@@ -81,6 +85,9 @@ class KeystoneClientTest(base.TestCase):
     @mock.patch('magnum.common.keystone.ka_v3')
     def test_client_with_password_legacy(self, mock_v3, mock_loading, mock_ks):
         self.ctx.is_admin = True
+        self.ctx.auth_token_info = None
+        self.ctx.auth_token = None
+        self.ctx.trust_id = None
         mock_loading.load_auth_from_conf_options.side_effect = \
             ka_exception.MissingRequiredOptions(mock.MagicMock())
         ks_client = keystone.KeystoneClientV3(self.ctx)
@@ -149,7 +156,7 @@ class KeystoneClientTest(base.TestCase):
         ks_client.create_trust(trustee_user='888888')
 
         mock_ks.return_value.trusts.create.assert_called_once_with(
-            delegation_depth=0,
+            allow_redelegation=False,
             trustor_user='123456', project='654321',
             trustee_user='888888', role_names=['role1', 'role2'],
             impersonation=True)
@@ -166,7 +173,7 @@ class KeystoneClientTest(base.TestCase):
         ks_client.create_trust(trustee_user='888888')
 
         mock_ks.return_value.trusts.create.assert_called_once_with(
-            delegation_depth=0,
+            allow_redelegation=False,
             trustor_user='123456', project='654321',
             trustee_user='888888', role_names=['role3'],
             impersonation=True)
